Crate reqmd_http

Crate reqmd_http 

Structs

Address
HTTP Address
HeaderLine
Represents a single header line with a key and value.
Headers
A list of key-value pairs representing HTTP headers.
Path
Http Path
QueryString
Query Parameters
Request
Request
RequestBuilder
Request Builder
RequestFactory
Request Factory
Response
ResponseBuilder
Response Builder
Status
Url
A parsed URL record.

Enums

Error
HTTP Request/Response Error Handling
Host
The host name of an URL.
Method
HTTP defines a set of request methods to indicate the purpose of the request and what is expected if the request is successful. Although they can also be nouns, these request methods are sometimes referred to as HTTP verbs. Each request method has its own semantics, but some characteristics are shared across multiple methods.
RequestBody
Body Content
ResponseBody
Scheme
HTTP scheme, either HTTP or HTTPS.

Traits

Client
HTTP Client Trait